@@ -5,7 +5,7 @@ from pydmt.builders.npm import Installer
 from pydmt.core.pydmt import PyDMT
 
 
-class Npm(Feature):
+class FeatureNpm(Feature):
     def setup(self, pydmt: PyDMT) -> None:
         if os.path.isfile("package.json"):
             pydmt.add_builder(Installer(
